read_mcsc_dir

Function read_mcsc_dir 

pub fn read_mcsc_dir<R, P: AsRef<Path>>(
    mcsc_dir: P,
    require_radfiles: bool,
) -> Result<McscDirData<R>>
Read the results of an MCSC calibration from a directory.

If require_radfiles is true, then an error will be returned if any camera does not have a corresponding .rad file. If false, then cameras without .rad files will be treated as having a linear distortion model.