pub struct FlydraMultiCameraSystem<R: RealField + Copy + Serialize> { /* private fields */ }Implementations
Sourceimpl<R: RealField + Copy + Default + Serialize> FlydraMultiCameraSystem<R>
impl<R: RealField + Copy + Default + Serialize> FlydraMultiCameraSystem<R>
pub fn from_system(system: MultiCameraSystem<R>, water: Option<R>) -> Self
pub fn has_refractive_boundary(&self) -> bool
pub fn water(&self) -> Option<R>
pub fn to_system(self) -> MultiCameraSystem<R>
pub fn system(&self) -> &MultiCameraSystem<R>
pub fn new(cams_by_name: BTreeMap<String, Camera<R>>, water: Option<R>) -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn cam_by_name(&self, name: &str) -> Option<MultiCamera<R>>
pub fn cam_names(&self) -> CamNameIter<'_, R> ⓘ
pub fn cameras<'a>(&'a self) -> MultiCameraIter<'a, R> ⓘ
pub fn find3d_and_cum_reproj_dist_distorted( &self, points: &[(String, DistortedPixel<R>)], ) -> Result<PointWorldFrameWithSumReprojError<R>>
Sourcepub fn find3d(
&self,
points: &[(String, UndistortedPixel<R>)],
) -> Result<PointWorldFrameMaybeWithSumReprojError<R>>
pub fn find3d( &self, points: &[(String, UndistortedPixel<R>)], ) -> Result<PointWorldFrameMaybeWithSumReprojError<R>>
Find 3D coordinate using pixel coordinates from cameras
If the system has water, two evaluations are done: one for the case of the 3D point being under water, the other for the case of the 3D point being in air. The evaluation with the lowest mean reprojection error is selected.
pub fn find3d_distorted( &self, points: &[(String, DistortedPixel<R>)], ) -> Result<WorldCoordAndUndistorted2D<R>>
Sourcepub fn get_reprojection_undistorted_dists(
&self,
points: &[(String, UndistortedPixel<R>)],
this_3d_pt: &PointWorldFrame<R>,
) -> Result<Vec<R>>
pub fn get_reprojection_undistorted_dists( &self, points: &[(String, UndistortedPixel<R>)], this_3d_pt: &PointWorldFrame<R>, ) -> Result<Vec<R>>
Find reprojection error of 3D coordinate into pixel coordinates
pub fn from_flydra_reconstructor(recon: &FlydraReconstructor<R>) -> Result<Self>
pub fn to_flydra_reconstructor(&self) -> Result<FlydraReconstructor<R>>
Sourceimpl<R> FlydraMultiCameraSystem<R>
impl<R> FlydraMultiCameraSystem<R>
pub fn from_mcsc_dir<P>(mcsc_dir: P, require_radfiles: bool) -> Result<Self>
pub fn from_flydra_xml<Rd: Read>(reader: Rd) -> Result<Self>
pub fn to_flydra_xml<W: Write>(&self, writer: W) -> Result<()>